h5_create_group: Create an HDF5 Group

h5_create_groupR Documentation

Create an HDF5 Group

Description

Explicitly creates a new group (or nested groups) in an HDF5 file. This is useful for creating an empty group structure.

Usage

h5_create_group(file, name)

Arguments

file

The path to the HDF5 file.

name

The full path of the group to create (e.g., "/g1/g2").

Value

Invisibly returns NULL. This function is called for its side effects.

Examples

file <- tempfile(fileext = ".h5")
h5_create_file(file)

# Create a nested group structure
h5_create_group(file, "/data/experiment/run1")
h5_ls(file)

unlink(file)

h5lite documentation built on May 19, 2026, 1:07 a.m.