| h5_create_group | R Documentation |
Explicitly creates a new group (or nested groups) in an HDF5 file. This is useful for creating an empty group structure.
h5_create_group(file, name)
file |
The path to the HDF5 file. |
name |
The full path of the group to create (e.g., "/g1/g2"). |
Invisibly returns NULL. This function is called for its side effects.
file <- tempfile(fileext = ".h5")
h5_create_file(file)
# Create a nested group structure
h5_create_group(file, "/data/experiment/run1")
h5_ls(file)
unlink(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.