A logical value: TRUE if the object exists and is a group,
FALSE otherwise (if it is a dataset, or does not exist).
Arguments
file
The path to the HDF5 file.
name
The full path of the object to check.
attr
The name of an attribute. This parameter is included for consistency with other functions.
Since attributes cannot be groups, providing this will always return FALSE. (Default: NULL)