| h5_typeof | R Documentation |
Returns the low-level HDF5 storage type of a dataset or an attribute (e.g., "int8", "float64", "utf8", "ascii[10]"). This allows inspecting the file storage type before reading the data into R.
h5_typeof(file, name, attr = NULL)
file |
The path to the HDF5 file. |
name |
Name of the dataset or object. |
attr |
The name of an attribute to check. If |
A character string representing the HDF5 storage type (e.g., "float32", "uint32", "ascii[10]", "compound[2]").
h5_class(), h5_exists()
file <- tempfile(fileext = ".h5")
h5_write(1L, file, "int32_val", as = "int32")
h5_typeof(file, "int32_val") # "int32"
h5_write(mtcars, file, "mtcars")
h5_typeof(file, "mtcars") # "compound[11]"
h5_write(c("a", "b", "c"), file, "strings")
h5_typeof(file, "strings") # "utf8[1]"
unlink(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.